@@ -78,7 +78,7 @@ static void restart_game ()
   new_game (NULL, &seed);
 };
 
-void random_seed ()
+static void new_game_action ()
 {
   if (waiting_for_mouse_up()) return;
   new_game (NULL, NULL);
@@ -120,25 +120,38 @@ static void help_about_callback (void)
 	  NULL
   };
 
+  const gchar *documenters[] = {
+	  "Rosanna Yuen (zana@webwynk.net)",
+	  NULL
+  };
+
   gtk_show_about_dialog (GTK_WINDOW (app),
 			 "name", _("AisleRiot"),
 			 "version", VERSION,
-			 "comments", _("AisleRiot provides a rule-based solitaire card engine "
-				       "that allows many different games to be played."),
-			 "copyright", "Copyright \xc2\xa9 1998-2005 Jonathan Blandford",
+			 "comments", _("AisleRiot provides a rule-based solitaire\n"
+				       "card engine that allows many different\n"
+				       "games to be played."),
+			 "copyright", "Copyright \xc2\xa9 1998-2006 Jonathan Blandford",
+			 "license", "GPL 2+",
 			 "authors", authors,
+			 "documenters", documenters,
 			 "translator_credits", _("translator-credits"),
+			 "logo-icon-name", "gnome-aisleriot.png",
+			 "website", "http://www.gnome.org/projects/gnome-games/",
+			 "wrap-license", TRUE,
 			 NULL);
 }
 
 static void general_help (void)
 {
-  gnome_help_display ("aisleriot.xml", NULL, NULL);
+  gnome_help_display_on_screen ("aisleriot.xml", NULL,
+				gtk_widget_get_screen (app), NULL);
 }
 
 static void help_on_specific_game (void)
 {
-  gnome_help_display ("aisleriot.xml", ugamename, NULL);
+  gnome_help_display_on_screen ("aisleriot.xml", ugamename,
+				gtk_widget_get_screen (app), NULL);
 }
 
 static void toolbar_toggle_callback(GtkToggleAction * togglebutton, 
@@ -222,7 +235,7 @@ static const GtkActionEntry actions[] = {
   { "OptionsMenu", NULL, "Options" /* not translated on purpose */ },
   { "HelpMenu", NULL, N_("_Help") },
 
-  { "NewGame", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL, G_CALLBACK (random_seed) },
+  { "NewGame", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL, G_CALLBACK (new_game_action) },
   { "RestartGame", GAMES_STOCK_RESTART_GAME, NULL, NULL, NULL, G_CALLBACK (restart_game) },
   { "Select", GTK_STOCK_INDEX, N_("_Select Game..."), "<Ctrl>o", N_("Play a different game"), G_CALLBACK (show_select_game_dialog) },
   { "Statistics", GTK_STOCK_ADD, N_("S_tatistics"), NULL, N_("Show gameplay statistics"), G_CALLBACK (show_statistics_dialog) },
@@ -398,8 +411,10 @@ static gint compress_options_to_int (SCM options_list)
   l = SCM_INUM (scm_length (options_list)) - 1;
   for (i=l; i>=0; i--) {
     entry  = scm_list_ref (options_list, SCM_MAKINUM (i));
-    bits <<= 1;
-    bits |= SCM_NFALSEP (scm_list_ref (entry, SCM_MAKINUM (1))) ? 1 : 0;
+    if (SCM_NFALSEP (scm_list_p (entry))) {
+      bits <<= 1;
+      bits |= SCM_NFALSEP (scm_list_ref (entry, SCM_MAKINUM (1))) ? 1 : 0;
+    }
   }
 
   return bits;
@@ -414,8 +429,10 @@ static void expand_options_from_int (SCM options_list, guint bits)
   l = SCM_INUM (scm_length (options_list));
   for (i=0; i<l; i++) {
     entry  = scm_list_ref (options_list, SCM_MAKINUM (i));
-    scm_list_set_x (entry, SCM_MAKINUM (1), bits & 1 ? SCM_BOOL_T : SCM_BOOL_F);
-    bits >>= 1;
+    if (SCM_NFALSEP (scm_list_p (entry))) {
+      scm_list_set_x (entry, SCM_MAKINUM (1), bits & 1 ? SCM_BOOL_T : SCM_BOOL_F);
+      bits >>= 1;
+    }
   }
 }
 
@@ -456,6 +473,7 @@ static void load_option_list (SCM options_list)
   g_free (keyname);
 
   expand_options_from_int (options_list, r);
+  cscmi_apply_options_lambda (options_list);
 }
 
 static void option_cb (GtkToggleAction *action, gint n)
@@ -476,15 +494,27 @@ static void option_cb (GtkToggleAction *action, gint n)
   cscmi_apply_options_lambda (options_list);
 }
 
+enum {
+  menu_normal,
+  menu_radio
+} menumodes;
+
 /* FIXME: This does not add an appropriate underscore. Is this easy? 
  * Maybe underscore the first letter that isn't underscored in another
  * menu. */
+/* To get radio buttons in the menu insert an atom into the option list
+ * in your scheme code. To get back out of radio-button mode insert 
+ * another atom. The exact value of the atoms is irrelevant - they merely
+ * trigger a toggle - but descriptive names like begin-exclusive and
+ * end-exclusive are probably a good idea. */
 void install_options_menu (gchar *name)
 {
   static int merge_id = 0;
   static GtkActionGroup *options_group = NULL;
   SCM options_list;
   gint l, i;
+  gint mode = menu_normal;
+  GSList *radiogroup = NULL;
 
   if (merge_id) {
     gtk_ui_manager_remove_ui (ui_manager, merge_id);
@@ -496,7 +526,7 @@ void install_options_menu (gchar *name)
     options_group = NULL;
   }
 
-  if (has_options ()) {
+  if (cscmi_has_options ()) {
     menuaction = gtk_action_group_get_action (action_group, "OptionsMenu");
     g_object_set (G_OBJECT (menuaction), "label", name, NULL);
 
@@ -520,22 +550,42 @@ void install_options_menu (gchar *name)
       /* Each entry in the options list is a list consisting of a name and 
 	 a variable. */
       entry = scm_list_ref (options_list, SCM_MAKINUM (i));
-      entryname = SCM_STRING_CHARS (scm_list_ref (entry, SCM_MAKINUM (0)));
-      entrystate = SCM_NFALSEP (scm_list_ref (entry, SCM_MAKINUM (1)));
-
-      g_snprintf (actionname, sizeof (actionname), "Option%d", i);
-
-      itemaction = gtk_toggle_action_new (actionname, entryname, 
-					  NULL, NULL);
-      g_signal_connect (G_OBJECT (itemaction), "toggled",
-			G_CALLBACK (option_cb), GINT_TO_POINTER (i));
-      gtk_action_group_add_action (action_group, GTK_ACTION (itemaction));
-      gtk_toggle_action_set_active (itemaction, entrystate);
-      g_object_unref (itemaction);
-
-      gtk_ui_manager_add_ui (ui_manager, merge_id, "/MainMenu/OptionsMenu",
-			     actionname, actionname,
-			     GTK_UI_MANAGER_MENUITEM, FALSE);
+      if (SCM_NFALSEP (scm_list_p (entry))) {
+	entryname = SCM_STRING_CHARS (scm_list_ref (entry, SCM_MAKINUM (0)));
+	entrystate = SCM_NFALSEP (scm_list_ref (entry, SCM_MAKINUM (1)));
+	
+	g_snprintf (actionname, sizeof (actionname), "Option%d", i);
+	
+	if (mode == menu_normal) { 
+	  itemaction = gtk_toggle_action_new (actionname, entryname, 
+					      NULL, NULL);
+	} else {
+	  itemaction = GTK_TOGGLE_ACTION (gtk_radio_action_new (actionname, 
+							 entryname, 
+							 NULL, NULL, i));
+	  gtk_radio_action_set_group (GTK_RADIO_ACTION (itemaction), radiogroup);
+	  radiogroup = gtk_radio_action_get_group (GTK_RADIO_ACTION (itemaction));
+	}
+	g_signal_connect (G_OBJECT (itemaction), "toggled",
+			  G_CALLBACK (option_cb), 
+			  GINT_TO_POINTER (i));
+	gtk_action_group_add_action (action_group, GTK_ACTION (itemaction));
+	gtk_toggle_action_set_active (itemaction, entrystate);
+	g_object_unref (itemaction);
+	
+	gtk_ui_manager_add_ui (ui_manager, merge_id, "/MainMenu/OptionsMenu",
+			       actionname, actionname,
+			       GTK_UI_MANAGER_MENUITEM, FALSE);
+      } else {
+	/* If we encounter an atom, change the mode. What the atom is doesn't
+	   really matter. */
+	if (mode == menu_normal) {
+	  mode = menu_radio;
+	  radiogroup = NULL; /* Start a new radio group. */
+	} else {
+	  mode = menu_normal;
+	}
+      }
     }
   } 
 }
