@@ -704,15 +704,16 @@ main (int argc, char *argv [])
                               GCONF_CLIENT_PRELOAD_NONE, NULL);
 
 #ifdef HAVE_GNOME
-        gnome_program_init ("Blackjack", VERSION,
-                            LIBGNOMEUI_MODULE,
-                            argc, argv,
-                            GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+        GnomeProgram *program;
+        program = gnome_program_init ("Blackjack", VERSION,
+                                      LIBGNOMEUI_MODULE,
+                                      argc, argv,
+                                      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 #endif
 
         gtk_widget_push_colormap (gdk_rgb_get_colormap ());
 
-        gtk_window_set_default_icon_from_file (PIXMAPDIR"/gnome-blackjack.png", NULL);
+        gtk_window_set_default_icon_name ("gnome-blackjack");
 
         bj_gconf_init (bj_gconf_client ());
 
@@ -722,5 +723,9 @@ main (int argc, char *argv [])
 
         g_free (variation);
 
+#ifdef HAVE_GNOME
+        g_object_unref (program);
+#endif
+
         return 0;
 }
