@@ -48,13 +48,18 @@ gint turn;		        /* current player */
 position selection={0, 0, 0};	/* last selected position */
 int timeout;			/* computer speed */
 
+GnomeProgram *program;
+
 /* Command-line handling. */
 static gint iturn = 1;
 static gchar * state = NULL;
-static const struct poptOption options[] = {
-  {"state", 's', POPT_ARG_STRING, &state, 0, "Set the state of the board at start-up.", NULL},
-  {"turn", 't', POPT_ARG_INT, &iturn, 0, "Set whose turn it is.", " 1 (Light) or 2 (Dark)"},
-  {NULL, '\0', POPT_ARG_NONE, NULL, 0, NULL, NULL}
+
+static const GOptionEntry options[] = {
+  {"state", 's', 0, G_OPTION_ARG_STRING, &state,
+   N_("Set the state of the board at start-up."), N_("STATE")},
+  {"turn", 't', 0, G_OPTION_ARG_INT, &iturn,
+   N_("Set whose turn it is."), N_("1 (Light) or 2 (Dark)")},
+  {NULL}
 };
 
 /* gettext i18n stuff */
@@ -178,10 +183,10 @@ gboolean end_game_cb(gpointer data) {
 	} else {
 		appbar_set_status(_("The game was a draw."));
 	}
-
-	flip_final (gridboard, wc, bc);
-	gtk_gridboard_paint (gridboard);
-
+	if (props_get_animate()) {
+		flip_final(gridboard, wc, bc);
+		gtk_gridboard_paint (gridboard);
+	}
 	return FALSE; /* kill the timeout */
 }
 
@@ -251,7 +256,7 @@ void do_select(int x, int y) {
 			}
 		}
 	}
-	gtk_gridboard_set_selection(gridboard, SELECTED_A, x, y);
+	gtk_gridboard_set_selection(gridboard, SELECTED_B, x, y);
 }
 
 /* Restore the state of the board from the command line. */
@@ -379,14 +384,23 @@ about_cb(GtkWidget *widget, gpointer data)
   const gchar *authors[] = {"Chris Rogers", "Sjoerd Langkemper", 
 			    N_("Based on code from Iagno by Ian Peters"), NULL};
 
+  const gchar *documenters[] = {"Aaron Weber", 
+			    	NULL};
+
   gtk_show_about_dialog (GTK_WINDOW (window),
 			 "name", _("Ataxx"), 
 			 "version", VERSION,
 			 "copyright", "Copyright \xc2\xa9 1999-2003 Chris Rogers\n"
-				      "Copyright \xc2\xa9 2004-2005 Sjoerd Langkemper",
+				      "Copyright \xc2\xa9 2004-2005 Sjoerd Langkemper\n"
+			              "Copyright \xc2\xa9 2005-2006 Callum McKenzie",
+			 "license", "GPL 2+",
 			 "comments", _("A disk-flipping game where you attempt to dominate the board."),
 			 "authors", authors,
+			 "documenters", documenters,
 			 "translator_credits", _("translator-credits"),
+			 "logo-icon-name", "gnome-ataxx",
+			 "website", "http://www.gnome.org/projects/gnome-games/",
+			 "wrap-license", TRUE,
 			 NULL);
 }
 
@@ -445,13 +459,17 @@ static gboolean save_state_cb (GnomeClient * client, gint phase,
 
 static void initgnomeclient(int argc, char ** argv) {
 	GnomeClient * client;
+        GOptionContext * option_context;
 
-	gnome_program_init("gataxx", VERSION,
-			LIBGNOMEUI_MODULE,
-			argc, argv,
-			GNOME_PARAM_POPT_TABLE, options,
-			GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gataxx.png");
+        option_context = g_option_context_new ("");
+        g_option_context_add_main_entries (option_context,
+                                           options, GETTEXT_PACKAGE);
+	program = gnome_program_init("gataxx", VERSION,
+				     LIBGNOMEUI_MODULE,
+				     argc, argv,
+                        	     GNOME_PARAM_GOPTION_CONTEXT, option_context,
+				     GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+	gtk_window_set_default_icon_name ("gnome-ataxx");
 	client=gnome_master_client();
 
 	g_signal_connect (G_OBJECT (client), "save_yourself",
@@ -534,6 +552,8 @@ int main(int argc, char ** argv) {
 
 	gtk_main();
 
+	g_object_unref (program);
+
 	return 0;
 }
 
