@@ -86,6 +86,8 @@ static void gtk_gridboard_init(GtkGridBoard * gridboard) {
         gridboard->height=0;
 	gridboard->statelist=NULL;
 	gridboard->theme = gtk_gridboard_themes;
+	/* We do our own double-buffering. */
+	gtk_widget_set_double_buffered(GTK_WIDGET (gridboard), FALSE);
 }
 
 GtkWidget * gtk_gridboard_new(gint width, gint height, char * theme) {
@@ -326,9 +328,13 @@ static void gtk_gridboard_repaint(GtkGridBoard * gridboard) {
 	  phase = gridboard->pixmaps[x][y];
 	  phase = (phase - 1.0)/30.0;
 	  gridboard->theme->draw_piece (cx, x, y, phase);
-	} else if (gridboard->selected[x][y]) {
+	} else if (gridboard->selected[x][y] == SELECTED_A) {
 	  gridboard->theme->draw_hilight (cx, x, y);
 	}
+	if (gridboard->selected[x][y] == SELECTED_B) {
+	  gridboard->theme->draw_secondary_hilight (cx, x, y, 
+						    gridboard->board[x][y]);
+	}
 	gridboard->changed[x][y] = FALSE;
       }
     }
