@@ -22,12 +22,13 @@
 #include <config.h>
 #include <gnome.h>
 #include <string.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <games-clock.h>
 #include <time.h>
 #include <gconf/gconf-client.h>
 #include <games-stock.h>
+#include <games-scores.h>
+#include <games-scores-dialog.h>
 
 #define APPNAME "gnotravex"
 #define APPNAME_LONG "Tetravex"
@@ -55,6 +56,19 @@ GtkWidget *space;
 GtkWidget *bit;
 GtkWidget *timer;
 
+static const GamesScoresCategory scorecats[] = {{"2x2", N_("2\303\2272")},
+                                                {"3x3", N_("3\303\2273")},
+                                                {"4x4", N_("4\303\2274")},
+                                                {"5x5", N_("5\303\2275")},
+                                                {"6x6", N_("6\303\2276")},
+                                                GAMES_SCORES_LAST_CATEGORY};
+static const GamesScoresDescription scoredesc = {scorecats,
+                                                 "3x3",
+                                                 "gnotravex",
+                                                 GAMES_SCORES_STYLE_TIME_ASCENDING};
+
+GamesScores *highscores;
+
 int xborder;
 int yborder;
 int gap;
@@ -87,7 +101,7 @@ enum {
   playing,
 };
 
-gint size = 3;
+gint size = -1;
 gint game_state = gameover;
 gint have_been_hinted = 0;
 gint solve_me = 0;
@@ -134,7 +148,6 @@ void move_tile (gint, gint, gint, gint);
 void move_column (unsigned char);
 gint game_over (void);
 void game_score (void);
-void update_score_state (void);
 gint timer_cb (void);
 void timer_start (void);
 void pause_game (void);
@@ -142,7 +155,7 @@ void resume_game (void);
 void pause_cb (void);
 void hint_move_cb (void);
 void hint_move (gint, gint, gint, gint);
-void show_score_dialog (const gchar *, gint);
+void show_score_dialog (gint);
 static gint save_state (GnomeClient*, gint, GnomeRestartStyle,
                         gint, GnomeInteractStyle, gint, gpointer);
 
@@ -237,13 +250,14 @@ const char ui_description[] =
 "</ui>";
 
 
-static const struct poptOption options[] = {
-  {NULL, 'x', POPT_ARG_INT, &session_xpos, 0, NULL, NULL},
-  {NULL, 'y', POPT_ARG_INT, &session_ypos, 0, NULL, NULL},
-  { "size", 's', POPT_ARG_INT, &size,0,
-    N_("Size of board (2-6)"),
-    N_("SIZE") },
-  { NULL, '\0', 0, NULL, 0 }
+static const GOptionEntry options[] = {
+  {"x", 'x', 0, G_OPTION_ARG_INT, &session_xpos, N_("X location of window"), 
+   N_("X")},
+  {"y", 'y', 0, G_OPTION_ARG_INT, &session_ypos, N_("Y location of window"), 
+   N_("Y")},
+  {"size", 's', 0, G_OPTION_ARG_INT, &size, N_("Size of board (2-6)"),
+    N_("SIZE")},
+  {NULL}
 };
 
 /* ------------------------------------------------------- */
@@ -252,25 +266,30 @@ int
 main (int argc, char **argv)
 {
   GnomeClient *client;
-
+  GnomeProgram *program;
+  GOptionContext *context;
   GtkWidget *vbox;
   GtkWidget *menubar;
   GtkUIManager *ui_manager;
   GtkAccelGroup *accel_group;  
 
-  gnome_score_init (APPNAME);
+  setgid_io_init ();
 
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  gnome_program_init (APPNAME, VERSION,
-      		      LIBGNOMEUI_MODULE, 
-       		      argc, argv,
-       		      GNOME_PARAM_POPT_TABLE, options,
-       		      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+  context = g_option_context_new ("");
+  g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+  program = gnome_program_init (APPNAME, VERSION,
+                                LIBGNOMEUI_MODULE, 
+       		                argc, argv,
+       		                GNOME_PARAM_GOPTION_CONTEXT, context,
+       		                GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+
+  highscores = games_scores_new (&scoredesc);
      
-  gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gnotravex.png");
+  gtk_window_set_default_icon_name ("gnome-tetravex");
   client = gnome_master_client ();
   g_object_ref (G_OBJECT (client));
   
@@ -283,7 +302,8 @@ main (int argc, char **argv)
 
   gconf_client = gconf_client_get_default();
 
-  size = gconf_client_get_int (gconf_client, KEY_GRID_SIZE, NULL);
+  if (size == -1)
+    size = gconf_client_get_int (gconf_client, KEY_GRID_SIZE, NULL);
   if (size < 2 || size > 6) 
     size = 3;
 
@@ -324,11 +344,12 @@ main (int argc, char **argv)
                     G_CALLBACK (button_release_space), NULL);
   g_signal_connect (G_OBJECT (space), "motion_notify_event",
                     G_CALLBACK (button_motion_space), NULL);
+  /* We do our own double-buffering. */
+  gtk_widget_set_double_buffered(space, FALSE);
+
   gtk_widget_show (space);
 
 
-  update_score_state ();
-
   if (session_xpos >= 0 && session_ypos >= 0)
     gtk_window_move (GTK_WINDOW (window), session_xpos, session_ypos);
     
@@ -342,6 +363,8 @@ main (int argc, char **argv)
   gtk_main ();
 
   gnome_accelerators_sync();
+
+  g_object_unref (program);
   
   return 0;
 }
@@ -935,15 +958,28 @@ game_over (void)
 }
 
 void
-show_score_dialog (const gchar *level, gint pos)
+show_score_dialog (gint pos)
 {
-  GtkWidget *dialog;
+  static GtkWidget *scoresdialog = NULL;
+  gchar *message;
 
-  dialog = gnome_scores_display (_(APPNAME_LONG), APPNAME, level, pos);
-  if (dialog != NULL) {
-    gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
-    gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+  if (!scoresdialog) {
+    scoresdialog = games_scores_dialog_new (highscores, _("Tetravex Scores"));
+    games_scores_dialog_set_category_description (GAMES_SCORES_DIALOG (scoresdialog), _("Size:"));
   }
+  if (pos > 0) {
+    games_scores_dialog_set_hilight (GAMES_SCORES_DIALOG (scoresdialog), pos);
+    message = g_strdup_printf ("<b>%s</b>\n\n%s",
+                               _("Congratulations!"),
+                               _("Your score has made the top ten."));
+    games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog), message);
+    g_free (message);
+  } else {
+    games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog), NULL);
+  }
+  
+  gtk_dialog_run (GTK_DIALOG (scoresdialog));
+  gtk_widget_hide (scoresdialog);
 }
 
 void
@@ -951,7 +987,7 @@ score_cb (GtkAction *action, gpointer data)
 {
   gchar *level;
   level = g_strdup_printf ("%dx%d", size, size);
-  show_score_dialog (level, 0);
+  show_score_dialog (0);
   g_free (level);
 }
 
@@ -960,40 +996,15 @@ game_score (void)
 {
   gint pos;
   time_t seconds;
-  gfloat score;
-  gchar *level;
+  GamesScoreValue score;
   
-  level = g_strdup_printf ("%dx%d", size, size);
   seconds = GAMES_CLOCK (timer)->stopped;
   games_clock_set_seconds (GAMES_CLOCK (timer), (int) seconds);
-  score = (gfloat) (seconds / 60) + (gfloat) (seconds % 60) / 100;
-  pos = gnome_score_log (score, level, FALSE);
-  update_score_state ();
-  show_score_dialog (level, pos);
-  g_free (level);
+  score.time_double = (gfloat) (seconds / 60) + (gfloat) (seconds % 60) / 100;
+  pos = games_scores_add_score (highscores, score);
+  show_score_dialog (pos);
 }
 
-void
-update_score_state (void)
-{
-  gchar **names = NULL;
-  gfloat *scores = NULL;
-  time_t *scoretimes = NULL;
-  gint top;
-  gchar *level;
-  
-  level = g_strdup_printf ("%dx%d", size, size);
-  
-  top = gnome_score_get_notable (APPNAME, level, &names, &scores, &scoretimes);
-  g_free (level);
-
-  gtk_action_set_sensitive (scores_action, top > 0);
-  g_strfreev (names);
-  g_free (scores);
-  g_free (scoretimes);
-}
-
-
 void
 update_tile_size (gint screen_width, gint screen_height)
 {
@@ -1402,7 +1413,7 @@ size_cb (GtkAction *action, gpointer data)
     return;
   size = newsize;
   update_tile_size (width, height);
-  update_score_state ();
+  games_scores_set_category (highscores, scorecats[size-2].key);
   gconf_client_set_int (gconf_client, KEY_GRID_SIZE, size, NULL);
   gtk_action_activate (new_game_action);
 }
@@ -1584,11 +1595,21 @@ about_cb (GtkAction *action, gpointer data)
 {
   const gchar *authors[] = { "Lars Rydlinge", NULL };
 
+  const gchar *documenters[] = { "Rob Bradford", NULL };
+
   gtk_show_about_dialog (GTK_WINDOW (window),
                          "name", _(APPNAME_LONG),
                          "version", VERSION,
-                         "copyright", "Copyright \xc2\xa9 1999-2005 Lars Rydlinge",
+                         "comments", _("GNOME Tetravex is a simple puzzle where "
+					     "pieces must be positioned so that the "
+					     "same numbers are touching each other."),
+                         "copyright", "Copyright \xc2\xa9 1999-2006 Lars Rydlinge",
+                         "license", "GPL 2+",
                          "authors", authors,
+                         "documenters", documenters,
                          "translator_credits", _("translator-credits"),
+                         "logo-icon-name", "gnome-tetravex",
+                         "website", "http://www.gnome.org/projects/gnome-games/",
+                         "wrap-license", TRUE,
                          NULL);
 }
